@@ -17,20 +17,13 @@
 # Copyright
 # Matt Newman (c) 1999 Novadigm Inc.
 # Stephen Uhler / Brent Welch (c) 1997 Sun Microsystems
+# Brent Welch (c) 1998-2000 Ajuba Solutions
 # See the file "license.terms" for information on usage and redistribution
 # of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 #
-# SCCS: @(#) httpd.tcl 1.16 97/07/12 14:29:54
+# RCS: @(#) $Id: httpd.tcl,v 1.51 2000/08/02 07:25:53 welch Exp $
 
-package provide httpd 1.2
-
-# The version.tcl file used to be part of httpd package, but
-# that confused the use of tcl_findLibrary because by loading
-# just version.tcl Tcl thought we had the whole package.  So
-# we split it out, but require it here so users of httpd don't
-# have to worry about httpd_version
-
-package require httpd_version
+package provide httpd 1.3
 
 # initialize all the global data
 
@@ -707,6 +700,7 @@ proc HttpdReadPost {sock varName blockSize {cmd {}}} {
 	if {$data(count)} {
 	    set doneMsg "Short read: got [string length $buffer] bytes,\
 		expected $data(count) more bytes"
+	    set data(count) 0
 	} else {
 	    set doneMsg ""
 	}
@@ -734,6 +728,7 @@ proc HttpdReadPost {sock varName blockSize {cmd {}}} {
 		$blockSize : $data(count)}]
 	if {[catch {read $sock $toRead} block]} {
 	    set doneMsg $block
+	    set data(count) 0
 	} else {
 	    if {[info exist buffer]} {
 		append buffer $block
@@ -1304,7 +1299,7 @@ proc Httpd_SockClose {sock closeit {message Close}} {
 	    set data(cancel) [after $Httpd(timeout3) \
 		[list HttpdCloseFinal $sock]]
 
-	    Httpd_GetPostDataAsync $sock "" HttpdCloseFinal
+	    Httpd_GetPostDataAsync $sock "" $data(count) HttpdCloseFinal
 	} else {
 	    HttpdCloseFinal $sock
 	}
